@@ -135,7 +135,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		return err
 	}
 
-	artifact := &artifact.Artifact{
+	a := &artifact.Artifact{
 		Type:    artifact.Binary,
 		Path:    options.Path,
 		Name:    options.Name,
@@ -151,6 +151,15 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		},
 	}
 
+	if build.Buildmode == "c-archive" {
+		a.Type = artifact.CArchive
+		ctx.Artifacts.Add(getHeaderArtifactForLibrary(build, options))
+	}
+	if build.Buildmode == "c-shared" {
+		a.Type = artifact.CShared
+		ctx.Artifacts.Add(getHeaderArtifactForLibrary(build, options))
+	}
+
 	details, err := withOverrides(ctx, build, options)
 	if err != nil {
 		return err
@@ -167,7 +176,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		"GOAMD64="+options.Goamd64,
 	)
 
-	cmd, err := buildGoBuildLine(ctx, build, details, options, artifact, env)
+	cmd, err := buildGoBuildLine(ctx, build, details, options, a, env)
 	if err != nil {
 		return err
 	}
@@ -177,7 +186,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 	}
 
 	if build.ModTimestamp != "" {
-		modTimestamp, err := tmpl.New(ctx).WithEnvS(env).WithArtifact(artifact, map[string]string{}).Apply(build.ModTimestamp)
+		modTimestamp, err := tmpl.New(ctx).WithEnvS(env).WithArtifact(a, map[string]string{}).Apply(build.ModTimestamp)
 		if err != nil {
 			return err
 		}
@@ -192,7 +201,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		}
 	}
 
-	ctx.Artifacts.Add(artifact)
+	ctx.Artifacts.Add(a)
 	return nil
 }
 
@@ -206,11 +215,12 @@ func withOverrides(ctx *context.Context, build config.Build, options api.Options
 
 		if optsTarget == overrideTarget {
 			dets := config.BuildDetails{
-				Ldflags:  build.BuildDetails.Ldflags,
-				Tags:     build.BuildDetails.Tags,
-				Flags:    build.BuildDetails.Flags,
-				Asmflags: build.BuildDetails.Asmflags,
-				Gcflags:  build.BuildDetails.Gcflags,
+				Buildmode: build.BuildDetails.Buildmode,
+				Ldflags:   build.BuildDetails.Ldflags,
+				Tags:      build.BuildDetails.Tags,
+				Flags:     build.BuildDetails.Flags,
+				Asmflags:  build.BuildDetails.Asmflags,
+				Gcflags:   build.BuildDetails.Gcflags,
 			}
 			if err := mergo.Merge(&dets, o.BuildDetails, mergo.WithOverride); err != nil {
 				return build.BuildDetails, err
@@ -228,6 +238,9 @@ func withOverrides(ctx *context.Context, build config.Build, options api.Options
 func buildGoBuildLine(ctx *context.Context, build config.Build, details config.BuildDetails, options api.Options, artifact *artifact.Artifact, env []string) ([]string, error) {
 	cmd := []string{build.GoBinary, build.Command}
 
+	// tags, ldflags, and buildmode, should only appear once, warning only to avoid a breaking change
+	validateUniqueFlags(details)
+
 	flags, err := processFlags(ctx, artifact, env, details.Flags, "")
 	if err != nil {
 		return cmd, err
@@ -266,10 +279,28 @@ func buildGoBuildLine(ctx *context.Context, build config.Build, details config.B
 		cmd = append(cmd, "-ldflags="+strings.Join(ldflags, " "))
 	}
 
+	if details.Buildmode != "" {
+		cmd = append(cmd, "-buildmode="+details.Buildmode)
+	}
+
 	cmd = append(cmd, "-o", options.Path, build.Main)
 	return cmd, nil
 }
 
+func validateUniqueFlags(details config.BuildDetails) {
+	for _, flag := range details.Flags {
+		if strings.HasPrefix(flag, "-tags") && len(details.Tags) > 0 {
+			log.WithField("flag", flag).WithField("tags", details.Tags).Warn("tags is defined twice")
+		}
+		if strings.HasPrefix(flag, "-ldflags") && len(details.Ldflags) > 0 {
+			log.WithField("flag", flag).WithField("ldflags", details.Ldflags).Warn("ldflags is defined twice")
+		}
+		if strings.HasPrefix(flag, "-buildmode") && details.Buildmode != "" {
+			log.WithField("flag", flag).WithField("buildmode", details.Buildmode).Warn("buildmode is defined twice")
+		}
+	}
+}
+
 func processFlags(ctx *context.Context, a *artifact.Artifact, env, flags []string, flagPrefix string) ([]string, error) {
 	processed := make([]string, 0, len(flags))
 	for _, rawFlag := range flags {
@@ -366,3 +397,26 @@ func hasMain(file *ast.File) bool {
 	}
 	return false
 }
+
+func getHeaderArtifactForLibrary(build config.Build, options api.Options) *artifact.Artifact {
+	fullPathWithoutExt := strings.TrimSuffix(options.Path, options.Ext)
+	basePath := filepath.Base(fullPathWithoutExt)
+	fullPath := fullPathWithoutExt + ".h"
+	headerName := basePath + ".h"
+
+	return &artifact.Artifact{
+		Type:    artifact.Header,
+		Path:    fullPath,
+		Name:    headerName,
+		Goos:    options.Goos,
+		Goarch:  options.Goarch,
+		Goamd64: options.Goamd64,
+		Goarm:   options.Goarm,
+		Gomips:  options.Gomips,
+		Extra: map[string]interface{}{
+			artifact.ExtraBinary: headerName,
+			artifact.ExtraExt:    ".h",
+			artifact.ExtraID:     build.ID,
+		},
+	}
+}
