@@ -91,6 +91,9 @@ func (Pipe) Run(ctx *context.Context) error {
 		filter := []artifact.Filter{artifact.Or(
 			artifact.ByType(artifact.Binary),
 			artifact.ByType(artifact.UniversalBinary),
+			artifact.ByType(artifact.Header),
+			artifact.ByType(artifact.CArchive),
+			artifact.ByType(artifact.CShared),
 		)}
 		if len(archive.Builds) > 0 {
 			filter = append(filter, artifact.ByIDs(archive.Builds...))
